package Bundle::Locale::CLDR::Southernafrica;

use version;

our $VERSION = version->declare('v0.29.0');

=head1 NAME Bundle::Locale::CLDR::Southernafrica

=head1 CONTENTS

Locale::CLDR::Locales::Af 0.29.0
Locale::CLDR::Locales::Zu 0.29.0
Locale::CLDR::Locales::Naq 0.29.0
Locale::CLDR::Locales::Af::Any 0.29.0
Locale::CLDR::Locales::En::Any 0.29.0
Locale::CLDR::Locales::Zu::Any 0.29.0
Locale::CLDR::Locales::Naq::Any 0.29.0
Locale::CLDR::Locales::Af::Any::Na 0.29.0
Locale::CLDR::Locales::Af::Any::Za 0.29.0
Locale::CLDR::Locales::En::Any::Bw 0.29.0
Locale::CLDR::Locales::En::Any::Ls 0.29.0
Locale::CLDR::Locales::En::Any::Na 0.29.0
Locale::CLDR::Locales::En::Any::Sz 0.29.0
Locale::CLDR::Locales::En::Any::Za 0.29.0
Locale::CLDR::Locales::Zu::Any::Za 0.29.0
Locale::CLDR::Locales::En::Any::001 0.29.0
Locale::CLDR::Locales::Naq::Any::Na 0.29.0

=cut

1;

